%Circular transducer beam pattern
clear all, close all
%For a general area S in the x-y plane, s.243.
%Aperture function for a small strip is q(x) = 2*r*u0*sin(alpha).
f = 1e+6;
w = 2*pi*f;
a = 0.005; %0.5 cm
c0 = 1500;
kappa = w/c0;
u0 = 1;
lambda = c0/f;
ratio = 0.005/(1500/f);


%Farfield solution
sym r
sym theta
J1 = besselj(1,kappa*a*sin(theta));
Phi = (pi*a^2*u0)/(4*pi*r)*(2*J1)/(kappa*a*sin(theta))*exp(1i*kappa*r);
Phi_f = matlabFunction(Phi);

z_l = 0.1:lambda/20:1;
vals = zeros(1,length(z_l));
for i=1:length(z_l)
    vals(i) = Phi_f(z_l(i),0.0001);
end 
figure(1)
plot(z_l,real(vals))

%Directivity
B = (2*J1)/(kappa*a*sin(theta));
B = matlabFunction(B);

dim_x = -pi/4:0.01:pi/4;
dim_y = -pi/4:0.01:pi/4;

tmp = B(dim_x);
figure(2)
plot(20*log10(abs(tmp)/max(tmp)))

n = 20;
th = linspace(0,2*pi,n);
xr = dim_x.'*cos(th);
zr = dim_x.'*sin(th);
yr = repmat(tmp.',1,n);
figure(3)
surf(xr,zr,yr)
axis([min(dim_x),max(dim_x),min(dim_y),max(dim_y),0,1])
xlabel('x')
ylabel('y')
zlabel('z')

%Nearfield solution
r_d = 0:lambda/14:1;
Phi_n = u0/(2*1i*kappa)*(exp(1i*kappa*sqrt(r_d.^2+a^2))-exp(1i*kappa.*r_d));
figure(4)
plot(r_d,Phi_n)

