clear all,close all

%======================== ACTUAL FILTER TRANSFER ==========================

% %Filter coefficients 
% %Filter 1
R11 = 2200;
C11 = 15e-12;
R12 = 27000;
C12 = 39e-12;

a1 = -1/(R11*C11);
b1 = (1/R12)*(1/C11 + 1/C12);
c1 = 1/(R11*R12*C11*C12);

num1 = [a1 0];
den1 = [1 b1 c1];
%Need control system toolbox to use double arguments
f = 0:100:3e6;
w = 2*pi*f;
h1 = freqs(num1,den1,w);

figure(1)
plot(f,20*log10(abs(h1)))

%Filter 2
R21 = 3300;
C21 = 5.6e-12;
R22 = 33000;
C22 = 15e-12;

a2 = -1/(R21*C21);
b2 = (1/R22)*(1/C21 + 1/C22);
c2 = 1/(R21*R22*C21*C22);

num2 = [a2 0];
den2 = [1 b2 c2];
h2 = freqs(num2,den2,w);

figure(2)
plot(f,20*log10(abs(h2)))
f = f/1e6;
figure(3)
subplot(2,1,1)
plot(f,20*log10(abs(h1.*h2)),'LineWidth',2)
hold on
plot(f,zeros(length(f),1),'r--')
xlabel('Frequency [MHz]')
ylabel('Amplification [DB]')
subplot(2,1,2)
plot(f,360/(2*pi)*angle(h1.*h2),'LineWidth',2)
hold on
plot(f,zeros(length(f),1),'r--')
xlabel('Frequency [MHz]')
ylabel('Phase [degrees]')


%======================== TUNING FILTER TRANSFER ==========================

% %Filter coefficients 
% %Filter 1
steps = 10;

%=========================== Part 1 of filter =============================
r11_s = 1000;
r11_e = 3000;

c11_s = 3e-12;
c11_e = 25e-12;

r12_s = 20000;
r12_e = 35000;

c12_s = 25e-12;
c12_e = 45e-12;

R11 = r11_s:(r11_e-r11_s)/steps:r11_e;
C11 = c11_s:(c11_e-c11_s)/steps:c11_e;
R12 = r12_s:(r12_e-r12_s)/steps:r12_e;
C12 = c12_s:(c12_e-c12_s)/steps:c12_e;

num1 = zeros(steps,2);
den1 = zeros(steps,3);

%=========================== Part 2 of filter =============================

r21_s = 2000;
r21_e = 4000;

c21_s = 1e-12;
c21_e = 10e-12;

r22_s = 25000;
r22_e = 40000;

c22_s = 3e-12;
c22_e = 25e-12;

R21 = r21_s:(r21_e-r21_s)/steps:r21_e;
C21 = c21_s:(c21_e-c21_s)/steps:c21_e;
R22 = r22_s:(r22_e-r22_s)/steps:r22_e;
C22 = c22_s:(c22_e-c22_s)/steps:c22_e;

num2 = zeros(steps,2);
den2 = zeros(steps,3);




%============================= CALC LOOP ==================================
f = 0:100:10e6;
w = 2*pi*f;

h1 = zeros(1,length(f));
h2 = zeros(1,length(f));

for i=1:steps
    a1 = -1/(R11(i)*C11(i));
    b1 = (1/R12(i))*(1/C11(i) + 1/C12(i));
    c1 = 1/(R11(i)*R12(i)*C11(i)*C12(i));
    
    a2 = -1/(R21(i)*C21(i));
    b2 = (1/R22(i))*(1/C21(i) + 1/C22(i));
    c2 = 1/(R21(i)*R22(i)*C21(i)*C22(i));

    num1(i,:) = [a1 0];
    den1(i,:) = [1 b1 c1];
    
    num2(i,:) = [a2 0];
    den2(i,:) = [1 b2 c2];
    
    %Need control system toolbox to use double arguments
    h1 = freqs(num1(i,:),den1(i,:),w);
    h2 = freqs(num2(i,:),den2(i,:),w);
    
    s = int2str(i);
    
    figure(4)
    plot(f,20*log10(abs(h1)),'color',rand(1,3),'DisplayName',s,'LineWidth',2)
    %legend('-DynamicLegend');
    legend('Location','NorthEastOutside')
    hold on
    
    figure(5)
    plot(f,20*log10(abs(h2)),'color',rand(1,3),'DisplayName',s,'LineWidth',2)
    %legend('-DynamicLegend');
    legend('Location','NorthEastOutside')
    hold on
    
    figure(6)
    plot(f,20*log10(abs(h2.*h1)),'color',rand(1,3),'DisplayName',s,'LineWidth',2)
    %legend('-DynamicLegend');
    legend('Location','NorthEastOutside')
    hold on
end





%= QUICK TEST =
%Best so far
ind = 9;
R11(9)
R12(9)
C11(9)
C12(9)

R21(9)
R22(9)
C21(9)
C22(9)


